var fetch = require('node-fetch')
var Session = require('../session')
var config = require('./config')

var Api = {}

Api._buildPath = function(resource) {
  return 'http://' + config.apiHost + ':' + config.apiPort +
    config.apiSlug + resource
}

Api._getHeaders = function() {
  var headers = {
    'Content-Type': 'application/json'
  }

  var token = Session.get('token')
  if (!!token || token === 'undefined') {
    headers.Authorization = 'Bearer ' + token
  }

  return headers
}

Api._request = function(resource, method, payload) {
  var url = this._buildPath(resource)

  var options = {
    body: payload ? JSON.stringify(payload) : undefined,
    headers: Api._getHeaders(),
    method: method
  }

  return fetch(url, options)
  .then(function(response) { return response.text() })
  .then(JSON.parse)
  .then(function(response) {
    // Response.fatal when mysql db fails, should be catched in server
    if (response.status === 'error' || response.fatal) {
      return Promise.reject(response)
    }
    return response
  })
  .catch(function(error) {
    return Promise.reject(error)
  })
}

Api.get = function(resource, payload) {
  return Api._request(resource, 'GET', payload)
}

Api.post = function(resource, payload) {
  return Api._request(resource, 'POST', payload)
}

Api.put = function(resource, payload) {
  return Api._request(resource, 'PUT', payload)
}

module.exports = Api
