var database = require('../../database')
var i18n = require('../../i18n')
var formatter = require('../../lib/formatter')
var Session = require('../../session')
var csvExporter = require('../../lib/csv-exporter')

var GridController = function() {}

GridController.prototype._loadHeaders = function(headers) {
  var self = this
  return Object.keys(headers).map(function(key) {
    return i18n.t(headers[key].label)
  })
}

GridController.prototype.init = function(scope) {
  var self = this
  var getData = null

  this.table = scope.table
  scope.headerRow = this._loadHeaders(scope.headers)
  scope.keys = Object.keys(scope.headers)

  this._listenToExportEvent(scope)

  getData = scope.query ?
    database.executeSql(scope.query) : this.loadData(this.table, scope.keys)

  getData.then(function(rows) {
    scope.rows = self._prepareRows(rows, self)
    self.scope = scope
    self._render(scope)
  })
}

GridController.prototype._prepareRows = function(rows) {
  var self = this
  rows.forEach(function(row) {
    if (row.hasOwnProperty('date')) self._formatField('date', row)
    if (row.hasOwnProperty('status')) self._formatField('status', row)
  })

  return rows
}

GridController.prototype._formatField = function(field, row) {
  row[field] = formatter[field](row[field])
}

GridController.prototype.loadData = function(table, headers) {
  return database.read(table, headers)
}

GridController.prototype._exportAsCsv = function() {
  return csvExporter(
    this.table.name, this.scope.rows, this.scope.headerRow, this.scope.keys
  )
}

GridController.prototype._listenToExportEvent = function(scope) {
  this.destroyListenerFn = scope.$on('grid:export-csv', this._exportAsCsv.bind(this))
}

GridController.prototype.destroy = function(scope) {
  this.destroyListenerFn()
}

GridController.prototype._render = function(scope) {
  if (!scope.$$phase) {
    scope.$digest()
  }
}

module.exports = GridController
