var database = require('../../database')
var itemTable = require('../../tables').item
var squel = require('squel')
var i18n = require('../../i18n')

var NUM_PAD = [
  ['7', '8', '9', '<'],
  ['4', '5', '6', '-'],
  ['1', '2', '3', '0']
]

var ItemSelectorController = function() {
}

ItemSelectorController.prototype.init = function(scope) {
  var self = this
  this.scope = scope
  this.lineId = scope.lineId
  this.lineTableName = scope.lineTableName
  this.isFirstClick = true

  this._getItem(this.lineId)
  .then(function(item) {
    scope.quantityLabel = i18n.t('LABEL_QUANTITY')
    self.itemQuantity = '' + item.quantity
    scope.itemName = item.name
    scope.itemQuantity = self.itemQuantity
    scope.numPad = NUM_PAD
    scope.onPadClick = self.onPadClick.bind(self)
    scope.onBlur = self.onBlur.bind(self)
    self._render()
  })
}

ItemSelectorController.prototype._getItem = function(lineId) {
  var self = this
  var query = squel.select()
    .from(this.lineTableName)
    .fields([this.lineTableName + '.quantity', itemTable.name + '.name'])
    .join(itemTable.name, null, itemTable.name + '.id == ' + this.lineTableName + '.itemId')
    .where(this.lineTableName + '.id = ?', this.lineId )

  return database.executeSql(query.toString())
    .then(function(result) {
      return result[0]
    })
}

ItemSelectorController.prototype.onPadClick = function(button) {
  var self = this
  if (!button) return

  var oldValue = this.itemQuantity
  var newValue = this._getQuantity(button)
  if (!this.isFirstClick && oldValue === newValue) return
  this.isFirstClick = false
  this.itemQuantity = newValue
  return this._updateQuantity()
    .then(function(){
      self.scope.itemQuantity = self.itemQuantity
      self._render()
    })
}

ItemSelectorController.prototype.onBlur = function(fieldName) {
  var filter = {}
  var field = this.scope.fields.find(function(field) {
    return field.name === fieldName
  })

  filter[fieldName] = field.getValue()
  return database.update(
    { name: this.lineTableName },
    filter,
    { id: this.lineId }
  )
}

ItemSelectorController.prototype._getQuantity = function(button) {
  if (button === '<') {
    if (this.itemQuantity.length == 1 ||
        (this.itemQuantity.length === 2 && this.itemQuantity[0] === '-'))
      return 0
    else
      return this.itemQuantity.slice(0, -1)
  }
  if (button === '-') {
    if (this.itemQuantity[0] == '-') return this.itemQuantity.substring(1)
    return '-' + this.itemQuantity
  }

  if (this.itemQuantity.length >= 6) return this.itemQuantity
  if (this.itemQuantity === 0) return button
  if (this.isFirstClick) return button
  return this.itemQuantity += button
}

ItemSelectorController.prototype._updateQuantity = function() {
  return database.update(
    { name: this.lineTableName },
    {'quantity': parseInt(this.itemQuantity, 10) },
    { id: this.lineId }
  )
}

ItemSelectorController.prototype._render = function() {
  if (!this.scope.$$phase) {
    this.scope.$digest()
  }
}

module.exports = ItemSelectorController
