var moment = require('moment')
var Promise = require('bluebird')

var Exporter = function(tableName) {
  this.directory = cordova.file.externalDataDirectory || cordova.file.documentsDirectory
  this._fileName = tableName + moment().format('x') + '.csv'
  this.type = 'text/csv'
}

Exporter.prototype.save = function(data) {
  var self = this
  var promise = new Promise(function(resolve, reject) {
    self.resolve = resolve
    self.reject = reject
  })

  this._blob = this._createBlob(data)
  this._save()
  return promise
}

Exporter.prototype._createBlob = function(data) {
  return new Blob([data], { type: this.type } )
}

Exporter.prototype._save = function() {
  window.resolveLocalFileSystemURL(this.directory, this._onDirectoryLoaded.bind(this))
}

Exporter.prototype._onDirectoryLoaded = function(directory) {
  directory.getFile(
    this._fileName, { create: true }, this._onSuccess.bind(this), this._onError.bind(this)
  )
}

Exporter.prototype._onSuccess = function(file) {
  var self = this
  file.createWriter(function(fileWriter) {
    fileWriter.seek(fileWriter.length)
    fileWriter.write(self._blob)
    return self.resolve(self.directory + self._fileName)
  })
}

Exporter.prototype._onError = function(error) {
  this.reject(new Error(error))
}

module.exports = Exporter
