var api = require('../../api')
var Session = require('../../session')
var TextField = require('../../directives/form/fields/text')
var PasswordField = require('../../directives/form/fields/password')
var i18n = require('../../i18n')
var alert = require('../../lib/alert')

var USERNAME_FIELD = 'username'
var PASSWORD_FIELD = 'password'

function LoginController(scope, state) {
  this.state = state
  scope.fields = this.getFormFields()
  scope.onSubmit = this.onFormSubmit.bind(this)

  scope.submitLabel = i18n.t('BUTTON_LOGIN')
}

LoginController.prototype.getFormFields = function() {
  return [
    TextField(USERNAME_FIELD).setRequired().setPlaceholder(i18n.t('FIELD_USERNAME')),
    PasswordField(PASSWORD_FIELD).setRequired().setPlaceholder(i18n.t('FIELD_PASSWORD'))
  ]
}

LoginController.prototype.onFormSubmit = function(values) {
  var self = this
  var username = values[USERNAME_FIELD]
  var payload = {
    username: username,
    password: values[PASSWORD_FIELD]
  }

  return api.post('/login', payload)
  .then(function(response) {
    Session.set({ token: response.token, username: username, language: response.language })
    i18n.setLocale(response.language)
    return alert.success()
  })
  .then(function() {
    return self.state.go('sync')
  })
  .catch(function(error) {
    Session.clear()
    return alert.error()
  })
}

module.exports = ['$scope', '$state', LoginController];