var deliveryNoteTable = require('../../../tables').deliveryNote
var deliveryNoteLineTable = require('../../../tables').deliveryNoteLine
var itemTable = require('../../../tables').item
var database = require('../../../database')
var squel = require('squel')
var footerButtons = require('./footer-buttons')
var CLOSED_STATUS = require('../../../lib/status/provider').closed
var apiSyncer = require('../../../api/sync')
var alert = require('../../../lib/alert')

var GRID_HEADERS = {
  itemName: { label: 'GRID_TH_NAME' },
  quantity: { label: 'GRID_TH_QUANTITY' }
}

var DeliveryNoteLineController = function(scope, state, rootScope) {
  var self = this

  this.scope = scope
  this.state = state
  scope.gridHeaders = GRID_HEADERS
  scope.gridTable = deliveryNoteLineTable
  scope.gridDataQuery = this.getDataQuery(scope.deliveryNoteId)
  scope.onLineClick = this.onLineClick.bind(this)

  this.deliveryNoteId = scope.deliveryNoteId

  this._isDraft(scope.deliveryNoteId)
  .then(function(deliveryNote) {
    self.scope.title = deliveryNote.name
    self.isDraft = deliveryNote.status
    if (!self.isDraft) {
      return scope.footerButtons = footerButtons.closed(rootScope)
    }

    return scope.footerButtons = footerButtons.draft(state, self.onClose.bind(self), self.onDelete.bind(self))
  })
  .then(function() {
    self._render()
  })
}

DeliveryNoteLineController.prototype._isDraft = function(deliveryNoteId) {
  return database.read(deliveryNoteTable, ['status', 'name'], { id: deliveryNoteId })
    .then(function(result) {
      return result[0]
    })
}

DeliveryNoteLineController.prototype.getDataQuery = function(deliveryNoteId) {
  return squel.select()
    .from(deliveryNoteLineTable.name)
    .fields([
      deliveryNoteLineTable.name + '.id',
      deliveryNoteLineTable.name + '.quantity'
    ])
    .field(itemTable.name + '.name', 'itemName')
    .join(itemTable.name, null, deliveryNoteLineTable.name + '.itemId = ' + itemTable.name + '.id')
    .where(deliveryNoteLineTable.name + '.deliveryNoteId = ?', deliveryNoteId)
    .toString()
}

DeliveryNoteLineController.prototype.onLineClick = function(deliveryNoteLineId) {
  if (!this.isDraft) return
  this.state.go('deliveryNoteLineEditor', { deliveryNoteLineId: deliveryNoteLineId })
}

DeliveryNoteLineController.prototype.onClose = function() {
  var self = this
  apiSyncer.syncTable(deliveryNoteTable, { id: this.deliveryNoteId })
  .then(function() {
    alert.success()
    self.state.go('deliveryNoteList')
  })
}

DeliveryNoteLineController.prototype.onDelete = function() {
  var self = this
  return database.delete(deliveryNoteLineTable, { deliveryNoteId: this.scope.deliveryNoteId })
  .then(function() {
    return database.delete(deliveryNoteTable, { id: self.scope.deliveryNoteId })
  })
  .then(function() {
    alert.success()
    self.state.go('deliveryNoteList')
  })
}

DeliveryNoteLineController.prototype._render = function() {
  if (!this.scope.$$phase) {
    this.scope.$digest()
  }
}

module.exports = DeliveryNoteLineController
