var TextField = require('../../../directives/form/fields/text')
var database = require('../../../database')
var DELIVERY_NOTE_TABLE = require('../../../tables').deliveryNote
var ORDER_TABLE = require('../../../tables').order
var uuidGenerator = require('../../../lib/uuid-generator')
var DRAFT_STATUS = require('../../../lib/status/provider').draft
var SelectField = require('../../../directives/form/fields/select')
var DateField = require('../../../directives/form/fields/date')
var Session = require('../../../session')
var moment = require('moment')
var i18n = require('../../../i18n')
var tableKeys = require('../../../lib/tables/keys')(ORDER_TABLE)
var alert = require('../../../lib/alert')

var DeliveryNoteNewItem = function(scope, state) {
  var self = this
  this.scope = scope
  this.state = state
  scope.onSubmit = this.onFormSubmit.bind(this)

  this.getFormFields()
  .then(function(fields) {
    scope.title = i18n.t('TITLE_CREATE_DELIVERY_NOTE')
    scope.fields = fields
  }).then(function() {
    self._render()
  })
}

DeliveryNoteNewItem.prototype.getFormFields = function() {
  return database.read(ORDER_TABLE, tableKeys, {})
    .then(function(options) {
      return [
        new TextField('name').setRequired().setPlaceholder(i18n.t('FIELD_NAME')),
        new SelectField('order', options),
        new DateField('date').setRequired()
      ]
    })
}

DeliveryNoteNewItem.prototype.onFormSubmit = function(formValues) {
  var self = this
  formValues.date = moment(formValues.date).format('YYYY-MM-DD H:mm:ss')
  formValues.id = uuidGenerator()
  formValues.status = DRAFT_STATUS
  formValues.orderId = formValues.order.id
  formValues.username = Session.get('username')
  delete formValues.order

  database.create(DELIVERY_NOTE_TABLE, formValues)
  .then(function() {
    alert.success()
    return self.state.go('deliveryNoteList')
  })
  .catch(function(error) {
    console.error(error)
    return alert.error()
  })
}

DeliveryNoteNewItem.prototype._render = function() {
  if (!this.scope.$$phase) {
    this.scope.$digest()
  }
}

module.exports = DeliveryNoteNewItem
