var ItemTable = require('../../../tables').item
var InventoryLineTable = require('../../../tables').inventoryLine
var squel = require('squel')
var database = require('../../../database')
var uuidGenerator = require('../../../lib/uuid-generator')
var alert = require('../../../lib/alert')
var eanScanner = require('../../../lib/ean-scanner')
var i18n = require('../../../i18n')

var GRID_HEADERS = {
  name: { label: 'GRID_TH_NAME' },
  listPrice: { label: 'GRID_TH_LIST_PRICE' }
}

var InventoryLineInserterController = function(scope) {
  this.inventoryId = scope.inventoryId
  scope.gridHeaders = GRID_HEADERS
  scope.gridTable = ItemTable

  scope.gridDataQuery = this.getDataQuery()
  scope.onLineClick = this.onLineClick.bind(this)

  scope.mainButtons = this._getMainButtons()
  scope.title = i18n.t('TITLE_ADD_ITEM')
}

InventoryLineInserterController.prototype.getDataQuery = function() {
  return squel.select()
    .from(ItemTable.name)
    .fields(['id', 'name', 'listPrice'])
    .toString()
}

InventoryLineInserterController.prototype._insertLineIntoInventory = function(itemId) {
  var data = {
    id: uuidGenerator(),
    inventoryId: this.inventoryId,
    itemId: itemId,
    quantity: 1
  }
  return database.create(InventoryLineTable, data)
    .then(function() {
      return alert.success()
    })
    .catch(function(error) {
      console.error(error)
      return alert.error()
    })
}

InventoryLineInserterController.prototype.scan = function() {
  var self = this
  return eanScanner.activate()
    .then(function(scan) {
      return self._getItemFromEan(scan.text)
    })
    .then(function(result) {
      if (result && result[0]) {
        return self._insertLineIntoInventory(result[0].id)
      }
      return Promise.reject(new Error('no item found'))
    })
    .catch(function(error) {
      alert.error('', i18n.t('MSG_NO_ITEM_FOUND'))
      return Promise.reject(error)
    })
}

InventoryLineInserterController.prototype._getItemFromEan = function(eanCode) {
  var query = squel.select()
    .from(ItemTable.name)
    .where('ean = ?', eanCode)

  return database.executeSql(query.toString())
}

InventoryLineInserterController.prototype.onLineClick = function(itemId) {
  return this._insertLineIntoInventory(itemId)
}

InventoryLineInserterController.prototype._getMainButtons = function() {
  var self = this
  return [{
    icon: 'ion-ios-barcode-outline',
    action: self.scan.bind(self)
  }]
}

module.exports = InventoryLineInserterController
