var inventoryTable = require('../../../tables').inventory
var inventoryLineTable = require('../../../tables').inventoryLine
var itemTable = require('../../../tables').item
var database = require('../../../database')
var squel = require('squel')
var footerButtons = require('./footer-buttons')
var CLOSED_STATUS = require('../../../lib/status/provider').closed
var apiSyncer = require('../../../api/sync')
var alert = require('../../../lib/alert')

var GRID_HEADERS = {
  itemName: { label: 'GRID_TH_NAME' },
  quantity: { label: 'GRID_TH_QUANTITY' }
}

var InventoryLineController = function(scope, state, rootScope) {
  var self = this

  this.scope = scope
  this.state = state
  scope.gridHeaders = GRID_HEADERS
  scope.gridTable = inventoryLineTable
  scope.gridDataQuery = this.getDataQuery(scope.inventoryId)
  scope.onLineClick = this.onLineClick.bind(this)

  this.inventoryId = scope.inventoryId

  this._isDraft(scope.inventoryId)
  .then(function(inventory) {
    self.scope.title = inventory.name
    self.isDraft = inventory.status
    if (!self.isDraft) {
      return scope.footerButtons = footerButtons.closed(rootScope)
    }

    return scope.footerButtons = footerButtons.draft(state, self.onClose.bind(self), self.onDelete.bind(self))
  })
  .then(function() {
    self._render()
  })
}

InventoryLineController.prototype._isDraft = function(inventoryId) {
  return database.read(inventoryTable, ['status', 'name'], { id: inventoryId })
    .then(function(result) {
      return result[0]
    })
}

InventoryLineController.prototype.getDataQuery = function(inventoryId) {
  return squel.select()
    .from(inventoryLineTable.name)
    .fields([
      inventoryLineTable.name + '.id',
      inventoryLineTable.name + '.quantity'
    ])
    .field(itemTable.name + '.name', 'itemName')
    .join(itemTable.name, null, inventoryLineTable.name + '.itemId = ' + itemTable.name + '.id')
    .where(inventoryLineTable.name + '.inventoryId = ?', inventoryId)
    .toString()
}

InventoryLineController.prototype.onLineClick = function(inventoryLineId) {
  if (!this.isDraft) return
  this.state.go('inventoryLineEditor', { inventoryLineId: inventoryLineId })
}

InventoryLineController.prototype.onClose = function() {
  var self = this
  apiSyncer.syncTable(inventoryTable, { id: this.inventoryId })
  .then(function() {
    alert.success()
    self.state.go('inventoryList')
  })
}

InventoryLineController.prototype.onDelete = function() {
  var self = this
  return database.delete(inventoryLineTable, { inventoryId: this.scope.inventoryId })
  .then(function() {
    return database.delete(inventoryTable, { id: self.scope.inventoryId })
  })
  .then(function() {
    alert.success()
    self.state.go('inventoryList')
  })
}

InventoryLineController.prototype._render = function() {
  if (!this.scope.$$phase) {
    this.scope.$digest()
  }
}

module.exports = InventoryLineController
