var TextField = require('../../../directives/form/fields/text')
var database = require('../../../database')
var INVENTORY_TABLE = require('../../../tables').inventory
var WAREHOUSE_TABLE = require('../../../tables').warehouse
var uuidGenerator = require('../../../lib/uuid-generator')
var DRAFT_STATUS = require('../../../lib/status/provider').draft
var SelectField = require('../../../directives/form/fields/select')
var DateField = require('../../../directives/form/fields/date')
var Session = require('../../../session')
var moment = require('moment')
var i18n = require('../../../i18n')
var tableKeys = require('../../../lib/tables/keys')(WAREHOUSE_TABLE)
var alert = require('../../../lib/alert')

var InventoryNewItem = function(scope, state) {
  var self = this
  this.scope = scope
  this.state = state
  scope.onSubmit = this.onFormSubmit.bind(this)

  this.getFormFields()
  .then(function(fields) {
    self.scope.title = i18n.t('TITLE_CREATE_INVENTORY')
    scope.fields = fields
  }).then(function() {
    self._render()
  })
}

InventoryNewItem.prototype.getFormFields = function() {
  return database.read(WAREHOUSE_TABLE, tableKeys, {})
    .then(function(options) {
      return [
        new TextField('name').setRequired().setPlaceholder(i18n.t('FIELD_NAME')),
        new SelectField('warehouse', options),
        new DateField('date').setRequired()
      ]
    })
}

InventoryNewItem.prototype.onFormSubmit = function(formValues) {
  var self = this
  formValues.date = moment(formValues.date).format('YYYY-MM-DD H:mm:ss')
  formValues.id = uuidGenerator()
  formValues.status = DRAFT_STATUS
  formValues.warehouseId = formValues.warehouse.id
  formValues.username = Session.get('username')
  delete formValues.warehouse

  database.create(INVENTORY_TABLE, formValues)
  .then(function() {
    alert.success()
    return self.state.go('inventoryList')
  })
  .catch(function(error) {
    console.error(error)
    return alert.error()
  })
}

InventoryNewItem.prototype._render = function() {
  if (!this.scope.$$phase) {
    this.scope.$digest()
  }
}

module.exports = InventoryNewItem
