var orderTable = require('../../../tables').order
var orderLineTable = require('../../../tables').orderLine
var itemTable = require('../../../tables').item
var database = require('../../../database')
var squel = require('squel')
var footerButtons = require('./footer-buttons')
var CLOSED_STATUS = require('../../../lib/status/provider').closed
var apiSyncer = require('../../../api/sync')
var alert = require('../../../lib/alert')

var GRID_HEADERS = {
  itemName: { label: 'GRID_TH_NAME' },
  quantity: { label: 'GRID_TH_QUANTITY' },
  amount: { label: 'GRID_TH_AMOUNT' }
}

var OrderLineController = function(scope, state, rootScope) {
  var self = this

  this.scope = scope
  this.state = state
  scope.gridHeaders = GRID_HEADERS
  scope.gridTable = orderLineTable
  scope.gridDataQuery = this.getDataQuery(scope.orderId)
  scope.onLineClick = this.onLineClick.bind(this)

  this.orderId = scope.orderId

  this._isDraft(scope.orderId)
  .then(function(order) {
    self.scope.title = order.name
    self.isDraft = order.status
    if (!self.isDraft) {
      return scope.footerButtons = footerButtons.closed(rootScope)
    }

    return scope.footerButtons = footerButtons.draft(state, self.onClose.bind(self), self.onDelete.bind(self))
  })
  .then(function() {
    self._render()
  })
}

OrderLineController.prototype._isDraft = function(orderId) {
  return database.read(orderTable, ['status', 'name'], { id: orderId })
    .then(function(result) {
      return result[0]
    })
}

OrderLineController.prototype.getDataQuery = function(orderId) {
  return squel.select()
    .from(orderLineTable.name)
    .fields([
      orderLineTable.name + '.id',
      orderLineTable.name + '.quantity'
    ])
    .field(itemTable.name + '.name', 'itemName')
    .join(itemTable.name, null, orderLineTable.name + '.itemId = ' + itemTable.name + '.id')
    .where(orderLineTable.name + '.orderId = ?', orderId)
    .toString()
}

OrderLineController.prototype.onLineClick = function(orderLineId) {
  if (!this.isDraft) return
  this.state.go('orderLineEditor', { orderLineId: orderLineId })
}

OrderLineController.prototype.onClose = function() {
  var self = this
  apiSyncer.syncTable(orderTable, { id: this.orderId })
  .then(function() {
    alert.success()
    self.state.go('orderList')
  })
}

OrderLineController.prototype.onDelete = function() {
  var self = this
  return database.delete(orderLineTable, { orderId: this.scope.orderId })
  .then(function() {
    return database.delete(orderTable, { id: self.scope.orderId })
  })
  .then(function() {
    alert.success()
    self.state.go('orderList')
  })
}

OrderLineController.prototype._render = function() {
  if (!this.scope.$$phase) {
    this.scope.$digest()
  }
}

module.exports = OrderLineController
