var orderTable = require('../../../tables').order
var warehouseTable = require('../../../tables').warehouse
var vendorTable = require('../../../tables').vendor
var database = require('../../../database')
var squel = require('squel')
var footerButtons = require('./footer-buttons')
var i18n = require('../../../i18n')

var GRID_HEADERS = {
  name: { label: 'GRID_TH_NAME' },
  date: { label: 'GRID_TH_DATE' },
  status: { label: 'GRID_TH_STATUS' },
  warehouseName: { label: 'GRID_TH_WAREHOUSE' },
  vendorName: { label: 'GRID_TH_VENDOR' }
}

var OrderListController = function(scope, state) {
  this.state = state
  scope.gridHeaders = GRID_HEADERS
  scope.gridTable = orderTable
  scope.onLineClick = this.onLineClick.bind(this)
  scope.gridDataQuery = this.getDataQuery()
  scope.footerButtons = footerButtons(state)
  scope.title = i18n.t('TITLE_ORDER')
}

OrderListController.prototype.getDataQuery = function() {
  return squel.select()
    .from(orderTable.name)
    .fields([
      orderTable.name + '.date',
      orderTable.name + '.id',
      orderTable.name + '.name',
      orderTable.name + '.status'
    ])
    .field(warehouseTable.name + '.name', 'warehouseName')
    .field(vendorTable.name + '.name', 'vendorName')
    .join(warehouseTable.name, null, orderTable.name + '.warehouseId = ' + warehouseTable.name + '.id')
    .join(vendorTable.name, null, orderTable.name + '.vendorId = ' + vendorTable.name + '.id')
    .toString()
}

OrderListController.prototype.onLineClick = function(lineId) {
  this.state.go('orderLine', {id: lineId})
}

module.exports = OrderListController
