var TextField = require('../../../directives/form/fields/text')
var database = require('../../../database')
var ORDER_TABLE = require('../../../tables').order
var WAREHOUSE_TABLE = require('../../../tables').warehouse
var VENDOR_TABLE = require('../../../tables').vendor
var uuidGenerator = require('../../../lib/uuid-generator')
var DRAFT_STATUS = require('../../../lib/status/provider').draft
var SelectField = require('../../../directives/form/fields/select')
var DateField = require('../../../directives/form/fields/date')
var Session = require('../../../session')
var moment = require('moment')
var i18n = require('../../../i18n')
var warehouseTableKeys = require('../../../lib/tables/keys')(WAREHOUSE_TABLE)
var vendorTableKeys = require('../../../lib/tables/keys')(VENDOR_TABLE)
var alert = require('../../../lib/alert')

var OrderNewItem = function(scope, state) {
  var self = this
  this.scope = scope
  this.state = state
  scope.onSubmit = this.onFormSubmit.bind(this)

  this.getFormFields()
  .then(function(fields) {
    scope.title = i18n.t('TITLE_CREATE_ORDER')
    scope.fields = fields
  }).then(function() {
    self._render()
  })
}

OrderNewItem.prototype.getFormFields = function() {
  return database.read(WAREHOUSE_TABLE, warehouseTableKeys, {})
    .then(function(warehouseOptions) {
      return database.read(VENDOR_TABLE, vendorTableKeys, {})
      .then(function(vendorOptions) {
        return [
          new TextField('name').setRequired().setPlaceholder(i18n.t('FIELD_NAME')),
          new SelectField('warehouse', warehouseOptions),
          new SelectField('vendor', vendorOptions),
          new DateField('date').setRequired()
        ]
      })
    })
}

OrderNewItem.prototype.onFormSubmit = function(formValues) {
  var self = this
  formValues.date = moment(formValues.date).format('YYYY-MM-DD H:mm:ss')
  formValues.id = uuidGenerator()
  formValues.status = DRAFT_STATUS
  formValues.warehouseId = formValues.warehouse.id
  formValues.username = Session.get('username')
  formValues.vendorId = formValues.vendor.id
  formValues.amount = 0
  delete formValues.warehouse
  delete formValues.vendor

  database.create(ORDER_TABLE, formValues)
  .then(function() {
    alert.success()
    return self.state.go('orderList')
  })
  .catch(function(error) {
    console.error(error)
    return alert.error()
  })
}

OrderNewItem.prototype._render = function() {
  if (!this.scope.$$phase) {
    this.scope.$digest()
  }
}

module.exports = OrderNewItem
