var TextField = require('../../../directives/form/fields/text')
var database = require('../../../database')
var apiSyncer = require('../../../api/sync')
var VENDOR_TABLE = require('../../../tables').vendor
var uuidGenerator = require('../../../lib/uuid-generator')
var DRAFT_STATUS = require('../../../lib/status/provider').draft
var EDITED_STATUS = require('../../../lib/status/provider').edited
var tableKeys = require('../../../lib/tables/keys')(VENDOR_TABLE)
var i18n = require('../../../i18n')
var alert = require('../../../lib/alert')

var VendorDetail = function(scope, state) {
  var self = this
  scope.onSubmit = this.onFormSubmit.bind(this)

  this.scope = scope
  this.state = state

  this._loadVendor()
  .then(function(values) {
    scope.fields = self._getFormFields(values[0])
    self._render()
  })
  .catch(function(error) {
    console.error(error)
  })
}

VendorDetail.prototype._getFormFields = function(values) {
  var fields =  [
    new TextField('name').setRequired().setPlaceholder(i18n.t('FIELD_NAME')),
    new TextField('phoneNumber').setPlaceholder(i18n.t('FIELD_PHONE_NUMBER'))
  ]

  values = values || {}
  values.name && fields[0].setValue(values.name)
  values.phoneNumber && fields[1].setValue(values.phoneNumber)

  return fields
}

VendorDetail.prototype._loadVendor = function() {
  this._loadSubmitButtonLabel(this.scope.vendorId)
  if (!this.scope.vendorId) {
    this.scope.title = i18n.t('TITLE_ADD_VENDOR')
    return Promise.resolve([])
  }
  this.scope.title = i18n.t('TITLE_EDIT_VENDOR')
  return database.read(VENDOR_TABLE, tableKeys, { id: this.scope.vendorId })
}

VendorDetail.prototype.onFormSubmit = function(formValues) {
  var self = this

  if (this.scope.vendorId) return this._updateVendor(formValues)
  return this._createVendor(formValues)
}

VendorDetail.prototype._createVendor = function(values) {
  var self = this
  values.id = uuidGenerator()
  values.status = DRAFT_STATUS
  return database.create(VENDOR_TABLE, values)
    .then(function() {
      self._syncTable()
    })
}

VendorDetail.prototype._updateVendor = function(values) {
  var self = this
  values.status = EDITED_STATUS
  return database.update(VENDOR_TABLE, values, { id: this.scope.vendorId })
    .then(function() {
      self._syncTable()
    })
}

VendorDetail.prototype._syncTable = function() {
  var self = this
  apiSyncer.syncTable(VENDOR_TABLE)
  .then(function() {
    alert.success()
    self.state.go('vendorList')
  })
  .catch(function(error) {
    alert.error()
    console.error(error)
  })
}

VendorDetail.prototype._loadSubmitButtonLabel = function(vendorId) {
  var label = vendorId ? i18n.t('BUTTON_EDIT') : i18n.t('BUTTON_CREATE')
  this.scope.submitLabel = label
}

VendorDetail.prototype._render = function() {
  if (!this.scope.$$phase) {
    this.scope.$digest()
  }
}

module.exports = VendorDetail
