var TextField = require('../../../directives/form/fields/text')
var database = require('../../../database')
var apiSyncer = require('../../../api/sync')
var WAREHOUSE_TABLE = require('../../../tables').warehouse
var uuidGenerator = require('../../../lib/uuid-generator')
var DRAFT_STATUS = require('../../../lib/status/provider').draft
var EDITED_STATUS = require('../../../lib/status/provider').edited
var tableKeys = require('../../../lib/tables/keys')(WAREHOUSE_TABLE)
var i18n = require('../../../i18n')
var alert = require('../../../lib/alert')

var WarehouseDetail = function(scope, state) {
  var self = this

  scope.onSubmit = this.onFormSubmit.bind(this)

  this.scope = scope
  this.state = state

  this._loadWarehouse()
  .then(function(values) {
    scope.fields = self._getFormFields(values[0])
    self._render()
  })
  .catch(function(error) {
    console.error(error)
  })
}

WarehouseDetail.prototype._getFormFields = function(values) {
  var fields = [
    new TextField('name').setRequired().setPlaceholder(i18n.t('FIELD_NAME'))
  ]

  values = values || {}
  values.name && fields[0].setValue(values.name)
  return fields
}

WarehouseDetail.prototype._loadWarehouse = function() {
  this._loadSubmitButtonLabel(this.scope.warehouseId)
  if (!this.scope.warehouseId) {
    this.scope.title = i18n.t('TITLE_ADD_WAREHOUSE')
    return Promise.resolve([])
  }
  this.scope.title = i18n.t('TITLE_EDIT_WAREHOUSE')
  return database.read(WAREHOUSE_TABLE, tableKeys, { id: this.scope.warehouseId })
}

WarehouseDetail.prototype.onFormSubmit = function(formValues) {
  var self = this

  if (this.scope.warehouseId) return this._updateVendor(formValues)
  return this._createVendor(formValues)
}

WarehouseDetail.prototype._createVendor = function(values) {
  var self = this
  values.id = uuidGenerator()
  values.status = DRAFT_STATUS
  return database.create(WAREHOUSE_TABLE, values)
    .then(function() {
      self._syncTable()
    })
}

WarehouseDetail.prototype._updateVendor = function(values) {
  var self = this
  values.status = EDITED_STATUS
  return database.update(WAREHOUSE_TABLE, values, { id: this.scope.warehouseId })
    .then(function() {
      self._syncTable()
    })
}

WarehouseDetail.prototype._syncTable = function() {
  var self = this
  return apiSyncer.syncTable(WAREHOUSE_TABLE)
  .then(function() {
    alert.success()
    self.state.go('warehouseList')
  })
  .catch(function(error) {
    alert.error()
    console.error(error)
  })
}

WarehouseDetail.prototype._loadSubmitButtonLabel = function(warehouseId) {
  var label = warehouseId ? i18n.t('BUTTON_EDIT') : i18n.t('BUTTON_CREATE')
  this.scope.submitLabel = label
}

WarehouseDetail.prototype._render = function() {
  if (!this.scope.$$phase) {
    this.scope.$digest()
  }
}

module.exports = WarehouseDetail
