var ItemTable = require('../../../tables').item
var WastageLineTable = require('../../../tables').wastageLine
var squel = require('squel')
var database = require('../../../database')
var uuidGenerator = require('../../../lib/uuid-generator')
var alert = require('../../../lib/alert')
var eanScanner = require('../../../lib/ean-scanner')
var i18n = require('../../../i18n')

var GRID_HEADERS = {
  name: { label: 'GRID_TH_NAME' },
  listPrice: { label: 'GRID_TH_LIST_PRICE' }
}

var WastageLineInserterController = function(scope) {
  this.wastageId = scope.wastageId
  scope.gridHeaders = GRID_HEADERS
  scope.gridTable = ItemTable

  scope.gridDataQuery = this.getDataQuery()
  scope.onLineClick = this.onLineClick.bind(this)
  scope.title = i18n.t('TITLE_ADD_ITEM')

  scope.mainButtons = this._getMainButtons()
}

WastageLineInserterController.prototype.getDataQuery = function() {
  return squel.select()
    .from(ItemTable.name)
    .fields(['id', 'name', 'listPrice'])
    .toString()
}

WastageLineInserterController.prototype._insertLineIntoWastage = function(itemId) {
  var data = {
    id: uuidGenerator(),
    wastageId: this.wastageId,
    itemId: itemId,
    quantity: 1,
    reason: ''
  }
  return database.create(WastageLineTable, data)
    .then(function() {
      return alert.success()
    })
    .catch(function(error) {
      console.error(error)
      return alert.error()
    })
}

WastageLineInserterController.prototype.scan = function() {
  var self = this
  return eanScanner.activate()
    .then(function(scan) {
      return self._getItemFromEan(scan.text)
    })
    .then(function(result) {
      if (result && result[0]) {
        return self._insertLineIntoWastage(result[0].id)
      }
      return Promise.reject(new Error('no item found'))
    })
    .catch(function(error) {
      alert.error('', i18n.t('MSG_NO_ITEM_FOUND'))
      return Promise.reject(error)
    })
}

WastageLineInserterController.prototype._getItemFromEan = function(eanCode) {
  var query = squel.select()
    .from(ItemTable.name)
    .where('ean = ?', eanCode)

  return database.executeSql(query.toString())
}

WastageLineInserterController.prototype.onLineClick = function(itemId) {
  return this._insertLineIntoWastage(itemId)
}

WastageLineInserterController.prototype._getMainButtons = function() {
  var self = this
  return [{
    icon: 'ion-ios-barcode-outline',
    action: self.scan.bind(self)
  }]
}

module.exports = WastageLineInserterController
