var wastageTable = require('../../../tables').wastage
var wastageLineTable = require('../../../tables').wastageLine
var itemTable = require('../../../tables').item
var database = require('../../../database')
var squel = require('squel')
var footerButtons = require('./footer-buttons')
var CLOSED_STATUS = require('../../../lib/status/provider').closed
var apiSyncer = require('../../../api/sync')
var alert = require('../../../lib/alert')

var GRID_HEADERS = {
  itemName: { label: 'GRID_TH_NAME' },
  quantity: { label: 'GRID_TH_QUANTITY' },
  reason: { label: 'GRID_TH_REASON' }
}

var WastageLineController = function(scope, state, rootScope) {
  var self = this

  this.scope = scope
  this.state = state
  scope.gridHeaders = GRID_HEADERS
  scope.gridTable = wastageLineTable
  scope.gridDataQuery = this.getDataQuery(scope.wastageId)
  scope.onLineClick = this.onLineClick.bind(this)

  this.wastageId = scope.wastageId

  this._isDraft(scope.wastageId)
  .then(function(wastage) {
    self.scope.title = wastage.name
    self.isDraft = wastage.status
    if (!self.isDraft) {
      return scope.footerButtons = footerButtons.closed(rootScope)
    }

    return scope.footerButtons = footerButtons.draft(state, self.onClose.bind(self), self.onDelete.bind(self))
  })
  .then(function() {
    self._render()
  })
}

WastageLineController.prototype._isDraft = function(wastageId) {
  return database.read(wastageTable, ['status', 'name'], { id: wastageId })
    .then(function(result) {
      return result[0]
    })
}

WastageLineController.prototype.getDataQuery = function(wastageId) {
  return squel.select()
    .from(wastageLineTable.name)
    .fields([
      wastageLineTable.name + '.id',
      wastageLineTable.name + '.quantity',
      wastageLineTable.name + '.reason'
    ])
    .field(itemTable.name + '.name', 'itemName')
    .join(itemTable.name, null, wastageLineTable.name + '.itemId = ' + itemTable.name + '.id')
    .where(wastageLineTable.name + '.wastageId = ?', wastageId)
    .toString()
}

WastageLineController.prototype.onLineClick = function(wastageLineId) {
  if (!this.isDraft) return
  this.state.go('wastageLineEditor', { wastageLineId: wastageLineId })
}

WastageLineController.prototype.onClose = function() {
  var self = this
  apiSyncer.syncTable(wastageTable, { id: this.wastageId })
  .then(function() {
    alert.success()
    self.state.go('wastageList')
  })
}

WastageLineController.prototype.onDelete = function() {
  var self = this
  return database.delete(wastageLineTable, { wastageId: this.scope.wastageId })
  .then(function() {
    return database.delete(wastageTable, { id: self.scope.wastageId })
  })
  .then(function() {
    alert.success()
    self.state.go('wastageList')
  })
}

WastageLineController.prototype._render = function() {
  if (!this.scope.$$phase) {
    this.scope.$digest()
  }
}

module.exports = WastageLineController
