CREATE TABLE User (
  id VARCHAR(36) NOT NULL,
  username VARCHAR(30) NOT NULL UNIQUE,
  password VARCHAR(270) NOT NULL,
  language VARCHAR(10) NOT NULL,
  PRIMARY KEY(id)
);

CREATE TABLE Item (
  id VARCHAR(36) NOT NULL UNIQUE,
  name VARCHAR(100) NOT NULL,
  price DECIMAL(6, 2) NOT NULL,
  listPrice DECIMAL(6, 2) NOT NULL,
  ean TEXT(13) NOT NULL,
  PRIMARY KEY(id)
);

CREATE TABLE Vendor(
  id VARCHAR(36) NOT NULL UNIQUE,
  name VARCHAR(50) NOT NULL,
  phoneNumber VARCHAR(20),
  PRIMARY KEY(id)
);

CREATE TABLE Warehouse(
  id VARCHAR(36) NOT NULL UNIQUE,
  name VARCHAR(50) NOT NULL,
  PRIMARY KEY(id)
);

INSERT INTO Warehouse (id, name) VALUES ('51e0b5d0-301f-11e7-aee4-a7d010954f21', 'Default');

CREATE TABLE Inventory (
  id VARCHAR(36) NOT NULL UNIQUE,
  warehouseId VARCHAR(36) NOT NULL,
  date DATETIME NOT NULL,
  name VARCHAR(50) NOT NULL,
  username VARCHAR(30) NOT NULL,
  PRIMARY KEY(id),
  FOREIGN KEY (warehouseId) REFERENCES Warehouse(id) ON DELETE CASCADE
);

CREATE TABLE InventoryLine (
  id VARCHAR(36) NOT NULL UNIQUE,
  inventoryId VARCHAR(36) NOT NULL,
  itemId VARCHAR(36) NOT NULL,
  quantity INTEGER,
  PRIMARY KEY(id),
  FOREIGN KEY (inventoryId) REFERENCES Inventory(id) ON DELETE CASCADE,
  FOREIGN KEY (itemId) REFERENCES Item(id) ON DELETE CASCADE
);

CREATE TABLE Orders (
  id VARCHAR(36) NOT NULL UNIQUE,
  warehouseId VARCHAR(36) NOT NULL,
  vendorId VARCHAR(36) NOT NULL,
  date DATETIME NOT NULL,
  name VARCHAR(50) NOT NULL,
  username VARCHAR(30) NOT NULL,
  amount DECIMAL(6, 2) NOT NULL,
  PRIMARY KEY(id),
  FOREIGN KEY (warehouseId) REFERENCES Warehouse(id) ON DELETE CASCADE,
  FOREIGN KEY (vendorId) REFERENCES Vendor(id) ON DELETE CASCADE
);

CREATE TABLE OrderLine (
  id VARCHAR(36) NOT NULL UNIQUE,
  orderId VARCHAR(36) NOT NULL,
  itemId VARCHAR(36) NOT NULL,
  quantity INTEGER,
  PRIMARY KEY(id),
  FOREIGN KEY (orderId) REFERENCES Orders(id) ON DELETE CASCADE,
  FOREIGN KEY (itemId) REFERENCES Item(id) ON DELETE CASCADE
);

CREATE TABLE Wastage (
  id VARCHAR(36) NOT NULL UNIQUE,
  warehouseId VARCHAR(36) NOT NULL,
  vendorId VARCHAR(36) NOT NULL,
  date DATETIME NOT NULL,
  name VARCHAR(50) NOT NULL,
  username VARCHAR(30) NOT NULL,
  PRIMARY KEY(id),
  FOREIGN KEY (warehouseId) REFERENCES Warehouse(id) ON DELETE CASCADE,
  FOREIGN KEY (vendorId) REFERENCES Vendor(id) ON DELETE CASCADE
);

CREATE TABLE WastageLine (
  id VARCHAR(36) NOT NULL UNIQUE,
  wastageId VARCHAR(36) NOT NULL,
  itemId VARCHAR(36) NOT NULL,
  quantity INTEGER,
  reason VARCHAR(36),
  PRIMARY KEY(id),
  FOREIGN KEY (wastageId) REFERENCES Wastage(id) ON DELETE CASCADE,
  FOREIGN KEY (itemId) REFERENCES Item(id) ON DELETE CASCADE
);

CREATE TABLE DeliveryNote (
  id VARCHAR(36) NOT NULL UNIQUE,
  orderId VARCHAR(36),
  date DATETIME NOT NULL,
  name VARCHAR(50) NOT NULL,
  username VARCHAR(30) NOT NULL,
  PRIMARY KEY(id),
  FOREIGN KEY (orderId) REFERENCES Orders(id) ON DELETE CASCADE
);

CREATE TABLE DeliveryNoteLine (
  id VARCHAR(36) NOT NULL UNIQUE,
  deliveryNoteId VARCHAR(36) NOT NULL,
  itemId VARCHAR(36) NOT NULL,
  quantity INTEGER,
  PRIMARY KEY(id),
  FOREIGN KEY (deliveryNoteId) REFERENCES DeliveryNote(id) ON DELETE CASCADE,
  FOREIGN KEY (itemId) REFERENCES Item(id) ON DELETE CASCADE
);
