import express from 'express'
import bodyParser from 'body-parser'
import services from './services'
import config from './config'

var router = express.Router()
var port = process.env.PORT || 8080

var app = express()
app.use(bodyParser.json())

let serviceNames = Object.keys(services)
serviceNames
  .filter((name) => typeof services[name].init == 'function')
  .forEach((name) => services[name].init(router, app))

serviceNames
  .filter((name) => typeof services[name].load == 'function')
  .forEach((name) => services[name].load(router))

app.use(function(req, res, next) {
  res.header('Access-Control-Allow-Origin', '*')
  res.header('Access-Control-Allow-Credentials', 'true')
  res.header('Access-Control-Allow-Methods', 'POST, GET, PUT, OPTIONS')
  res.header('Access-Control-Allow-Headers', 'Origin, X-Requested-With, Content-Type, Accept, Authorization')
  next()
})

app.use(config.apiPath, router)

app.use(function(err, req, res, next) {
  if (!!err.status) {
    return res.status(err.status).json( { message: err.message } )
  }
  return res.status(500).json({ message: 'Internal error' })
})

app.listen(port)
console.log('Magic happens on port ' + port)