import executeSQL from '../db/mysql'
import squel from 'squel'

class AbstractService {

  constructor (tableName, resource, httpMethods) {
    this.tableName = tableName
    this.resource = resource
    this.httpMethods = httpMethods
  }

  get (req) {
    const query = squel.select().field('*').from(this.tableName)
    return executeSQL(query.toString())
  }

  post (req) {
    throw new Error('Method not implemented')
  }

  put (req) {
    throw new Error('AbstractService:  not implemented')
  }

  _execute (req, res, httpMethod) {
    return this[httpMethod](req)
    .then((result) => res.json(result))
    .catch((error) => res.json(error))
  }

  load (router) {
    this.httpMethods.forEach((httpMethod) => {
      router[httpMethod](this.resource, (req, res) => { this._execute(req, res, httpMethod) })
    })
  }
}

export default AbstractService
