import passport from 'passport'
import {Strategy as LocalStrategy} from 'passport-local'
import jwt from 'jsonwebtoken'
import ejwt from 'express-jwt'
import config from '../config'
import Promise from 'bluebird'
import {getUser} from '../db/mysql'
import password from 'password-hash-and-salt'

var loginService = {

  _validatePassword: function(inputPasswd, dbPasswd) {
    var resolve, reject
    var promise = new Promise(function(_resolve, _reject) {
      resolve = _resolve
      reject = _reject
    })

    password(inputPasswd).verifyAgainst(dbPasswd, function(error, hash) {
      if (error) {
        reject(error)
      } else {
        resolve(hash)
      }
    })
    return promise
  },

  /**
   * Sets the callback to be executed to check the credentials
  **/
  _initPassport: function() {
    let self = this
    passport.use(new LocalStrategy(function(username, inputPasswd, done) {
      getUser(username)
        .filter((user) => user.username == username )
        .filter((user) => self._validatePassword(inputPasswd, user.password) )
        .then(function(user) {
          done(null, user[0])
        })
        .catch(function(error) {
          done(error, false)
        })
    }))
  },

  /**
   * Will require the token for all routes except the login one
  **/
  _initExpressJWT: function(app) {
    app.use(ejwt({
      secret: config.secret,
      userProperty: 'tokenPayload'
    }).unless({path: ['/api/login']}))
  },

  init: function(router, app) {
    app.use(passport.initialize())
    this._initPassport()
    this._initExpressJWT(app)
  },

  /**
   * Deferred passport authenticate execution.
  **/
  _execute: function(...args) {
    var resolve, reject
    var promise = new Promise(function(_resolve, _reject) {
      resolve = _resolve
      reject = _reject
    })
    passport.authenticate('local', function(error, user, info) {
      if (error) { return reject(error) }
      if (!user) {
        return reject({
          code: 401,
          message: { status: 'error', code: 'wrong credentials' }
        })
      }
      return resolve(user)
    })(...args)
    return promise
  },

  /**
   * Main function
   * Returns the token if credentials are right
   * Returns 401 if credentials are wrong
  **/
  load: function(router) {
    router.post('/login', (req, res, next) => {
      this._execute(req, res, next)
      .then(function(user) {
        res.json({ token: jwt.sign({id: user.id}, config.secret), language: user.language })
      })
      .catch(function(error) {
        error.code  ? res.status(error.code).json(error.message)
                      : next(error)
      })
    })
  }
}

export default loginService